%Script to calculate T1 noise in an indirect dimension 
%caused by MAS instability.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Enter Variables in this part of the script
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Enter value of T2* for indirect FID in us, 1000 = 1 ms, 2000 = 2 ms, etc.
T2=250
%Enter value of T2' of 1H in us, 1000 = 1 ms, 2000 = 2 ms, etc.
T2_1H=500
%Give the dwell in us, ie. 20 = 20 us, 10 = 10 us, etc.
dwell=10
%Give number of points in FID
points=500
%Enter relative size of correlated HMQC signal as compared to the
%uncorrelated and background magnetization, 0.01, 0.1, 0.5, 0.8, etc.
CorrelatedIntensity=0.05
%Enter set MAS frequency in Hz
MASFreq=50000
%Enter sigma (uncertainty) for MAS frequency distribution in Hz
sigma=1
%Give number of scans per point in the indirect dimension 8, 16, 32, etc.
%must be even number
scans=16

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Parameters to simulate HMQC profile from SIMPSON.
%HMQC profiles were fit using a mixture of gauss/lorentz functions.
%sigma values entered below are unique to each HMQC pulse sequence and
%1H CSA values.
%Correlated signal profile
%Enter sigma value for the gaussian function
s_g_corr=85
%Enter sigma value for the lorentzian function
s_l_corr=200

%Unorrelated signal profile
%Enter sigma value for the gaussian function
s_g_uncorr=200
%Enter sigma value for the lorentzian function
s_l_uncorr=190

%Offset factor for the l/g simulations of the uncorrelated signal
%This value is subtracted from the calculated l/g uncorr signal amplitude
I_uncorr_offset=0.756295316
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%Calculated part of the script
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%calculate T2 of correlated signal - depends on 1H T2' and X T2*
T2_corr=((1/T2)+(1/T2_1H))^-1
%calculate the T2 of uncorrelated signal - depends on 1H T2' only
T2_uncorr=T2_1H
%Calculate the acquisition time (length) of the FID
acqtime=dwell*points
%calculate the time values for the FID
times=dwell*([0:(points-1)]');
%calculate the amplitude of the correlated signal FID 
%with an exponential function
amplitude_corr=exp(-(times.^2/T2_corr.^2));
%calculate the amplitude of the uncorrelated signal FID 
%with an exponential function
amplitude_uncorr=exp(-times/T2_uncorr);
%creates zeroed column vector same length as amplitude vector give above.
%noiseFID will hold the noised FID output by the loop below.
noiseFID= zeros(1,points)';

%nested loop to randomize MAS, frequency modify the intensity points
%in the FID and output the noised FID
for j = 1:points
    for i = 1:(scans/2)
    %%calculate random MAS frequency
    MASrandom=(random('Normal',MASFreq,sigma));
    
    %calculate normalized gaussian/lorentzian HMQC profiles 
    %of correlated signal
    gauss_corr=exp(-0.5*((MASrandom-MASFreq)/s_g_corr)^2);
    lorentz_corr=((s_l_corr^2)/4)*(1/(((MASrandom-MASFreq)^2)+(0.5*s_l_corr)^2));
    CorrAmp=gauss_corr*lorentz_corr;
    
    %calculate normalized gaussian/lorentzian HMQC profiles 
    %of uncorrelated signal
    gauss_uncorr=exp(-0.5*((MASrandom-50000)/s_g_uncorr)^2);
    lorentz_uncorr=((s_l_uncorr^2)/4)*(1/(((MASrandom-MASFreq)^2)+(0.5*s_l_uncorr)^2));
    UncorrAmp=(gauss_uncorr*lorentz_uncorr)-I_uncorr_offset;
        
    corr_ans1=CorrelatedIntensity*CorrAmp*amplitude_corr(j);
    uncorr_ans1=(1-CorrelatedIntensity)*UncorrAmp*amplitude_uncorr(j);
    
    MASrandom=(random('Normal',MASFreq,sigma));
    
    %calculate normalized gaussian/lorentzian HMQC profiles 
    %of correlated signal
    gauss_corr=exp(-0.5*((MASrandom-MASFreq)/s_g_corr)^2);
    lorentz_corr=((s_l_corr^2)/4)*(1/(((MASrandom-MASFreq)^2)+(0.5*s_l_corr)^2));
    CorrAmp=gauss_corr*lorentz_corr;
    
    %calculate normalized gaussian/lorentzian HMQC profiles 
    %of uncorrelated signal
    gauss_uncorr=exp(-0.5*((MASrandom-50000)/s_g_uncorr)^2);
    lorentz_uncorr=((s_l_uncorr^2)/4)*(1/(((MASrandom-MASFreq)^2)+(0.5*s_l_uncorr)^2));
    UncorrAmp=(gauss_uncorr*lorentz_uncorr)-I_uncorr_offset;
    
    corr_ans2=CorrelatedIntensity*CorrAmp*amplitude_corr(j);
    uncorr_ans2=(1-CorrelatedIntensity)*UncorrAmp*amplitude_uncorr(j);
    
    noiseFID(j)=corr_ans1+corr_ans2+uncorr_ans1-uncorr_ans2+noiseFID(j);
    end
end

spec=real(fft(noiseFID));      %FT
spec=spec/max(spec);            %normalize
sw=1e3/dwell;
ax=(-points/2+1:points/2)/points*sw;    %frequency axis in kHz
%plot(ax,spec);                  %plot
%xlabel('khz')                   %axis label
%ylabel('intensity')

%plot(times,noiseFID);                  %plot
%xlabel('Time (\mus)')                   %axis label
%ylabel('Intensity')